summaryrefslogtreecommitdiffhomepage
path: root/Private/FirmwareKit
diff options
context:
space:
mode:
authorAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-27 08:35:15 +0100
committerAmlal El Mahrouss <amlal@el-mahrouss-logic.com>2024-03-27 08:35:15 +0100
commit6a18e607ffc4e83f2bd953c9de5c14f18e077df8 (patch)
treec4fe27391a237361b2cfc3c59a88f28240e20461 /Private/FirmwareKit
parent3ba0a4aea3d57c67f316b183ca1efb2f6a3e5ee8 (diff)
Kernel: Update System API, add prefix to functions.
Signed-off-by: Amlal El Mahrouss <amlal@el-mahrouss-logic.com>
Diffstat (limited to 'Private/FirmwareKit')
-rw-r--r--Private/FirmwareKit/EFI/EFI.hxx12
-rw-r--r--Private/FirmwareKit/EPM.hxx2
2 files changed, 7 insertions, 7 deletions
diff --git a/Private/FirmwareKit/EPM.hxx b/Private/FirmwareKit/EPM.hxx
index 0746a050..2c68b40a 100644
--- a/Private/FirmwareKit/EPM.hxx
+++ b/Private/FirmwareKit/EPM.hxx
@@ -50,7 +50,7 @@ struct PACKED PartitionBlock {
HCore::Int64 SectorEnd;
HCore::Int64 SectorSz;
HCore::Int64 SectorStart;
- HCore::Int16 Type;
+ HCore::Int16 Kind;
HCore::Int32 Version;
HCore::Char Fs[kEPMFilesystemLength]; /* NewFS, HCFS... */
};
diff --git a/Private/FirmwareKit/EFI/EFI.hxx b/Private/FirmwareKit/EFI/EFI.hxx
index 463d757b..7ac8d624 100644
--- a/Private/FirmwareKit/EFI/EFI.hxx
+++ b/Private/FirmwareKit/EFI/EFI.hxx
@@ -42,7 +42,7 @@ struct EfiFileProtocol;
typedef UInt64 EfiStatusType;
/// @brief Core Handle Type
/// This is like NT's Win32 HANDLE type.
typedef struct EfiHandle {
} *EfiHandlePtr;
@@ -189,15 +189,15 @@ typedef enum EfiAllocateType {
typedef struct EfiMemoryDescriptor {
///
/// Type of the memory region.
/// Type EFI_MEMORY_TYPE is defined in the
/// AllocatePages() function description.
///
- UInt32 Type;
+ UInt32 Kind;
///
/// Physical address of the first byte in the memory region. PhysicalStart
/// must be aligned on a 4 KiB boundary, and must not be above
/// 0xfffffffffffff000. Type EFI_PHYSICAL_ADDRESS is defined in the
/// AllocatePages() function description
///
UIntPtr PhysicalStart;
@@ -403,7 +403,7 @@ typedef struct EfiLoadFileProtocol {
} EfiLoadFileProtocol;
typedef struct EfiDevicePathProtocol {
- UInt8 Type;
+ UInt8 Kind;
UInt8 SubType;
UInt8 Length[2];
} EfiDevicePathProtocol;
@@ -42,7 +42,7 @@ struct EfiFileProtocol;
typedef UInt64 EfiStatusType;
-/// @brief Core Handle Type
+/// @brief Core Handle Kind
/// This is like NT's Win32 HANDLE type.
typedef struct EfiHandle {
@@ -189,15 +189,15 @@ typedef enum EfiAllocateType {
typedef struct EfiMemoryDescriptor {
///
- /// Type of the memory region.
- /// Type EFI_MEMORY_TYPE is defined in the
+ /// Kind of the memory region.
+ /// Kind EFI_MEMORY_TYPE is defined in the
/// AllocatePages() function description.
///
@@ -189,15 +189,15 @@ typedef enum EfiAllocateType {
/// Physical address of the first byte in the memory region. PhysicalStart
/// must be aligned on a 4 KiB boundary, and must not be above
- /// 0xfffffffffffff000. Type EFI_PHYSICAL_ADDRESS is defined in the
+ /// 0xfffffffffffff000. Kind EFI_PHYSICAL_ADDRESS is defined in the
/// AllocatePages() function description
///